/* tracker-iso-query.c generated by valac 0.34.0.71-0c51, the Vala compiler
 * generated from tracker-iso-query.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libtracker-sparql/tracker-sparql.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_TRACKER_ISO_QUERY (boxes_tracker_iso_query_get_type ())
#define BOXES_TRACKER_ISO_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQuery))
#define BOXES_TRACKER_ISO_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQueryClass))
#define BOXES_IS_TRACKER_ISO_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TRACKER_ISO_QUERY))
#define BOXES_IS_TRACKER_ISO_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TRACKER_ISO_QUERY))
#define BOXES_TRACKER_ISO_QUERY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQueryClass))

typedef struct _BoxesTrackerISOQuery BoxesTrackerISOQuery;
typedef struct _BoxesTrackerISOQueryClass BoxesTrackerISOQueryClass;
typedef struct _BoxesTrackerISOQueryPrivate BoxesTrackerISOQueryPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_tracker_iso_query_unref0(var) ((var == NULL) ? NULL : (var = (boxes_tracker_iso_query_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesTrackerIsoQueryNewData BoxesTrackerIsoQueryNewData;
typedef struct _BoxesTrackerIsoQueryFetchNextIsoDataData BoxesTrackerIsoQueryFetchNextIsoDataData;
typedef struct _BoxesParamSpecTrackerISOQuery BoxesParamSpecTrackerISOQuery;

struct _BoxesTrackerISOQuery {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesTrackerISOQueryPrivate * priv;
};

struct _BoxesTrackerISOQueryClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesTrackerISOQuery *self);
};

struct _BoxesTrackerISOQueryPrivate {
	TrackerSparqlCursor* cursor;
};

struct _BoxesTrackerIsoQueryNewData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GType object_type;
	BoxesTrackerISOQuery* self;
	TrackerSparqlConnection* connection;
	gchar* iso_query;
	gchar* _tmp0_;
	TrackerSparqlCursor* cursor;
	TrackerSparqlConnection* _tmp1_;
	TrackerSparqlCursor* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	TrackerSparqlCursor* _tmp5_;
	gboolean _tmp6_;
	TrackerSparqlCursor* _tmp7_;
	gboolean _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	TrackerSparqlCursor* _tmp11_;
	TrackerSparqlConnection* _tmp12_;
	const gchar* _tmp13_;
	TrackerSparqlCursor* _tmp14_;
	TrackerSparqlCursor* _tmp15_;
	GError * _inner_error_;
};

struct _BoxesTrackerIsoQueryFetchNextIsoDataData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesTrackerISOQuery* self;
	gchar* path;
	gchar* title;
	gchar* os_id;
	gchar* media_id;
	gchar** lang_list;
	gint lang_list_length1;
	gboolean result;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gboolean _tmp6_;
	TrackerSparqlCursor* _tmp7_;
	gboolean _tmp8_;
	GFile* file;
	TrackerSparqlCursor* _tmp9_;
	const gchar* _tmp10_;
	GFile* _tmp11_;
	GFile* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar** _tmp20_;
	gint _tmp21_;
	gboolean _tmp22_;
	TrackerSparqlCursor* _tmp23_;
	const gchar* _tmp24_;
	gchar* _tmp25_;
	TrackerSparqlCursor* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	TrackerSparqlCursor* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	TrackerSparqlCursor* _tmp32_;
	gint _tmp33_;
	gint _tmp34_;
	gchar* languages;
	TrackerSparqlCursor* _tmp35_;
	const gchar* _tmp36_;
	gchar* _tmp37_;
	gchar** _tmp38_;
	gint _tmp38__length1;
	gint __tmp38__size_;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	gchar** _tmp41_;
	gchar** _tmp42_;
	gchar** _tmp43_;
	gchar** _tmp44_;
	gint _tmp44__length1;
	GError * _inner_error_;
};

struct _BoxesParamSpecTrackerISOQuery {
	GParamSpec parent_instance;
};


static gpointer boxes_tracker_iso_query_parent_class = NULL;

gpointer boxes_tracker_iso_query_ref (gpointer instance);
void boxes_tracker_iso_query_unref (gpointer instance);
GParamSpec* boxes_param_spec_tracker_iso_query (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_tracker_iso_query (GValue* value, gpointer v_object);
void boxes_value_take_tracker_iso_query (GValue* value, gpointer v_object);
gpointer boxes_value_get_tracker_iso_query (const GValue* value);
GType boxes_tracker_iso_query_get_type (void) G_GNUC_CONST;
#define BOXES_TRACKER_ISO_QUERY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQueryPrivate))
enum  {
	BOXES_TRACKER_ISO_QUERY_DUMMY_PROPERTY
};
#define BOXES_TRACKER_ISO_QUERY_LANG_QUERY "ASK { osinfo:language a <http://www.w3.org/1999/02/22-rdf-syntax-ns#Pr" \
"operty> }"
#define BOXES_TRACKER_ISO_QUERY_ISO_QUERY "SELECT nie:url(?iso)   nie:title(?iso)\n" "       osinfo:id(?iso) osinfo:mediaId(?iso)\n" "{ ?iso nfo:isBootable true }"
#define BOXES_TRACKER_ISO_QUERY_ISO_QUERY_LANG "SELECT nie:url(?iso)   nie:title(?iso)\n" "       osinfo:id(?iso) osinfo:mediaId(?iso) osinfo:language(?iso)\n" "{ ?iso nfo:isBootable true }"
static void boxes_tracker_iso_query_construct_data_free (gpointer _data);
void boxes_tracker_iso_query_new (TrackerSparqlConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesTrackerISOQuery* boxes_tracker_iso_query_new_finish (GAsyncResult* _res_, GError** error);
void boxes_tracker_iso_query_construct (GType object_type, TrackerSparqlConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesTrackerISOQuery* boxes_tracker_iso_query_construct_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_tracker_iso_query_construct_co (BoxesTrackerIsoQueryNewData* _data_);
static void boxes_tracker_iso_query_new_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_tracker_iso_query_fetch_next_iso_data_data_free (gpointer _data);
void boxes_tracker_iso_query_fetch_next_iso_data (BoxesTrackerISOQuery* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_tracker_iso_query_fetch_next_iso_data_finish (BoxesTrackerISOQuery* self, GAsyncResult* _res_, gchar** path, gchar** title, gchar** os_id, gchar** media_id, gchar*** lang_list, int* lang_list_length1, GError** error);
static gboolean boxes_tracker_iso_query_fetch_next_iso_data_co (BoxesTrackerIsoQueryFetchNextIsoDataData* _data_);
static void boxes_tracker_iso_query_fetch_next_iso_data_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static gchar** _vala_array_dup7 (gchar** self, int length);
static void boxes_tracker_iso_query_finalize (BoxesTrackerISOQuery* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void boxes_tracker_iso_query_construct_data_free (gpointer _data) {
	BoxesTrackerIsoQueryNewData* _data_;
	_data_ = _data;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (_data_->connection);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_boxes_tracker_iso_query_unref0 (_data_->self);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_slice_free (BoxesTrackerIsoQueryNewData, _data_);
#line 192 "tracker-iso-query.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return self ? g_object_ref (self) : NULL;
#line 199 "tracker-iso-query.c"
}


void boxes_tracker_iso_query_construct (GType object_type, TrackerSparqlConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesTrackerIsoQueryNewData* _data_;
	TrackerSparqlConnection* _tmp0_ = NULL;
	TrackerSparqlConnection* _tmp1_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_ = g_slice_new0 (BoxesTrackerIsoQueryNewData);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_tracker_iso_query_construct);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_tracker_iso_query_construct_data_free);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->object_type = object_type;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_tmp0_ = connection;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (_data_->connection);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->connection = _tmp1_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	boxes_tracker_iso_query_construct_co (_data_);
#line 225 "tracker-iso-query.c"
}


BoxesTrackerISOQuery* boxes_tracker_iso_query_construct_finish (GAsyncResult* _res_, GError** error) {
	BoxesTrackerISOQuery* result;
	BoxesTrackerIsoQueryNewData* _data_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return;
#line 236 "tracker-iso-query.c"
	}
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	result = _data_->self;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->self = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return result;
#line 246 "tracker-iso-query.c"
}


static void boxes_tracker_iso_query_new_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesTrackerIsoQueryNewData* _data_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_ = _user_data_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_source_object_ = source_object;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_res_ = _res_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	boxes_tracker_iso_query_construct_co (_data_);
#line 260 "tracker-iso-query.c"
}


static gboolean boxes_tracker_iso_query_construct_co (BoxesTrackerIsoQueryNewData* _data_) {
	BoxesTrackerISOQuery* self = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	switch (_data_->_state_) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		case 0:
#line 270 "tracker-iso-query.c"
		goto _state_0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		case 1:
#line 274 "tracker-iso-query.c"
		goto _state_1;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		case 2:
#line 278 "tracker-iso-query.c"
		goto _state_2;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		case 3:
#line 282 "tracker-iso-query.c"
		goto _state_3;
		default:
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_assert_not_reached ();
#line 287 "tracker-iso-query.c"
	}
	_state_0:
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->self = (BoxesTrackerISOQuery*) g_type_create_instance (_data_->object_type);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp0_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp0_ = g_strdup (BOXES_TRACKER_ISO_QUERY_ISO_QUERY);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->iso_query = _data_->_tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp1_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp1_ = _data_->connection;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_state_ = 1;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	tracker_sparql_connection_query_async (_data_->_tmp1_, BOXES_TRACKER_ISO_QUERY_LANG_QUERY, NULL, boxes_tracker_iso_query_new_ready, _data_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return FALSE;
#line 308 "tracker-iso-query.c"
	_state_1:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp2_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp2_ = tracker_sparql_connection_query_finish (_data_->_tmp1_, _data_->_res_, &_data_->_inner_error_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->cursor = _data_->_tmp2_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_error_free (_data_->_inner_error_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->iso_query);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (_data_->_state_ == 0) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 328 "tracker-iso-query.c"
		} else {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 332 "tracker-iso-query.c"
		}
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_object_unref (_data_->_async_result);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 338 "tracker-iso-query.c"
	}
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp5_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp5_ = _data_->cursor;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_state_ = 2;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	tracker_sparql_cursor_next_async (_data_->_tmp5_, NULL, boxes_tracker_iso_query_new_ready, _data_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return FALSE;
#line 350 "tracker-iso-query.c"
	_state_2:
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp6_ = FALSE;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp6_ = tracker_sparql_cursor_next_finish (_data_->_tmp5_, _data_->_res_, &_data_->_inner_error_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp4_ = _data_->_tmp6_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_error_free (_data_->_inner_error_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_object_unref0 (_data_->cursor);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->iso_query);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (_data_->_state_ == 0) {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 372 "tracker-iso-query.c"
		} else {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 376 "tracker-iso-query.c"
		}
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_object_unref (_data_->_async_result);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 382 "tracker-iso-query.c"
	}
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (_data_->_tmp4_) {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp7_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp7_ = _data_->cursor;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp8_ = FALSE;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp8_ = tracker_sparql_cursor_get_boolean (_data_->_tmp7_, 0);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp3_ = _data_->_tmp8_;
#line 396 "tracker-iso-query.c"
	} else {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp3_ = FALSE;
#line 400 "tracker-iso-query.c"
	}
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (_data_->_tmp3_) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp9_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp9_ = g_strdup (BOXES_TRACKER_ISO_QUERY_ISO_QUERY_LANG);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->iso_query);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->iso_query = _data_->_tmp9_;
#line 412 "tracker-iso-query.c"
	}
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp10_ = NULL;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp10_ = _data_->iso_query;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_debug ("tracker-iso-query.vala:21: Tracker SPARQL query: %s", _data_->_tmp10_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp12_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp12_ = _data_->connection;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp13_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp13_ = _data_->iso_query;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_state_ = 3;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	tracker_sparql_connection_query_async (_data_->_tmp12_, _data_->_tmp13_, NULL, boxes_tracker_iso_query_new_ready, _data_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return FALSE;
#line 434 "tracker-iso-query.c"
	_state_3:
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp14_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp14_ = tracker_sparql_connection_query_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp11_ = _data_->_tmp14_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_error_free (_data_->_inner_error_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_object_unref0 (_data_->cursor);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->iso_query);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (_data_->_state_ == 0) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 456 "tracker-iso-query.c"
		} else {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 460 "tracker-iso-query.c"
		}
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_object_unref (_data_->_async_result);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 466 "tracker-iso-query.c"
	}
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp15_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp15_ = _data_->_tmp11_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp11_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (_data_->self->priv->cursor);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->self->priv->cursor = _data_->_tmp15_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (_data_->_tmp11_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (_data_->cursor);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->iso_query);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (_data_->_state_ == 0) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 488 "tracker-iso-query.c"
	} else {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 492 "tracker-iso-query.c"
	}
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_object_unref (_data_->_async_result);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return FALSE;
#line 498 "tracker-iso-query.c"
}


void boxes_tracker_iso_query_new (TrackerSparqlConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	boxes_tracker_iso_query_construct (BOXES_TYPE_TRACKER_ISO_QUERY, connection, _callback_, _user_data_);
#line 505 "tracker-iso-query.c"
}


BoxesTrackerISOQuery* boxes_tracker_iso_query_new_finish (GAsyncResult* _res_, GError** error) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return boxes_tracker_iso_query_construct_finish (_res_, error);
#line 512 "tracker-iso-query.c"
}


static void boxes_tracker_iso_query_fetch_next_iso_data_data_free (gpointer _data) {
	BoxesTrackerIsoQueryFetchNextIsoDataData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_boxes_tracker_iso_query_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_slice_free (BoxesTrackerIsoQueryFetchNextIsoDataData, _data_);
#line 523 "tracker-iso-query.c"
}


static gpointer _boxes_tracker_iso_query_ref0 (gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return self ? boxes_tracker_iso_query_ref (self) : NULL;
#line 530 "tracker-iso-query.c"
}


void boxes_tracker_iso_query_fetch_next_iso_data (BoxesTrackerISOQuery* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesTrackerIsoQueryFetchNextIsoDataData* _data_;
	BoxesTrackerISOQuery* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_ = g_slice_new0 (BoxesTrackerIsoQueryFetchNextIsoDataData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_tracker_iso_query_fetch_next_iso_data);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_tracker_iso_query_fetch_next_iso_data_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_tmp0_ = _boxes_tracker_iso_query_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	boxes_tracker_iso_query_fetch_next_iso_data_co (_data_);
#line 549 "tracker-iso-query.c"
}


gboolean boxes_tracker_iso_query_fetch_next_iso_data_finish (BoxesTrackerISOQuery* self, GAsyncResult* _res_, gchar** path, gchar** title, gchar** os_id, gchar** media_id, gchar*** lang_list, int* lang_list_length1, GError** error) {
	gboolean result;
	BoxesTrackerIsoQueryFetchNextIsoDataData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 560 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (path) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*path = _data_->path;
#line 568 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->path);
#line 572 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->path = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (title) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*title = _data_->title;
#line 580 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->title);
#line 584 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->title = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (os_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*os_id = _data_->os_id;
#line 592 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->os_id);
#line 596 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->os_id = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (media_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*media_id = _data_->media_id;
#line 604 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->media_id);
#line 608 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->media_id = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (lang_list) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*lang_list = _data_->lang_list;
#line 616 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 620 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (lang_list_length1) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*lang_list_length1 = _data_->lang_list_length1;
#line 626 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->lang_list = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return result;
#line 634 "tracker-iso-query.c"
}


static void boxes_tracker_iso_query_fetch_next_iso_data_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesTrackerIsoQueryFetchNextIsoDataData* _data_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_ = _user_data_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_source_object_ = source_object;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_res_ = _res_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	boxes_tracker_iso_query_fetch_next_iso_data_co (_data_);
#line 648 "tracker-iso-query.c"
}


static gchar** _vala_array_dup7 (gchar** self, int length) {
	gchar** result;
	int i;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	result = g_new0 (gchar*, length + 1);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	for (i = 0; i < length; i++) {
#line 659 "tracker-iso-query.c"
		gchar* _tmp0_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_tmp0_ = g_strdup (self[i]);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		result[i] = _tmp0_;
#line 665 "tracker-iso-query.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return result;
#line 669 "tracker-iso-query.c"
}


static gboolean boxes_tracker_iso_query_fetch_next_iso_data_co (BoxesTrackerIsoQueryFetchNextIsoDataData* _data_) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	switch (_data_->_state_) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		case 0:
#line 678 "tracker-iso-query.c"
		goto _state_0;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		case 1:
#line 682 "tracker-iso-query.c"
		goto _state_1;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		case 2:
#line 686 "tracker-iso-query.c"
		goto _state_2;
		default:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_assert_not_reached ();
#line 691 "tracker-iso-query.c"
	}
	_state_0:
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->media_id);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->media_id = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp0_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp0_ = _data_->media_id;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp1_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp1_ = g_strdup (_data_->_tmp0_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->os_id);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->os_id = _data_->_tmp1_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp2_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp2_ = _data_->os_id;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp3_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp3_ = g_strdup (_data_->_tmp2_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->title);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->title = _data_->_tmp3_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp4_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp4_ = _data_->title;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp5_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp5_ = g_strdup (_data_->_tmp4_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->path);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->path = _data_->_tmp5_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->lang_list = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->lang_list_length1 = 0;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp7_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp7_ = _data_->self->priv->cursor;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_state_ = 1;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	tracker_sparql_cursor_next_async (_data_->_tmp7_, NULL, boxes_tracker_iso_query_fetch_next_iso_data_ready, _data_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return FALSE;
#line 750 "tracker-iso-query.c"
	_state_1:
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp8_ = FALSE;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp8_ = tracker_sparql_cursor_next_finish (_data_->_tmp7_, _data_->_res_, &_data_->_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp6_ = _data_->_tmp8_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_error_free (_data_->_inner_error_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (_data_->_state_ == 0) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 768 "tracker-iso-query.c"
		} else {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 772 "tracker-iso-query.c"
		}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_object_unref (_data_->_async_result);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 778 "tracker-iso-query.c"
	}
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (!_data_->_tmp6_) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->result = FALSE;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (_data_->_state_ == 0) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 788 "tracker-iso-query.c"
		} else {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 792 "tracker-iso-query.c"
		}
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_object_unref (_data_->_async_result);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 798 "tracker-iso-query.c"
	}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp9_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp9_ = _data_->self->priv->cursor;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp10_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp10_ = tracker_sparql_cursor_get_string (_data_->_tmp9_, 0, NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp11_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp11_ = g_file_new_for_uri (_data_->_tmp10_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->file = _data_->_tmp11_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp12_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp12_ = _data_->file;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp13_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp13_ = g_file_get_path (_data_->_tmp12_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->path);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->path = _data_->_tmp13_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp14_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp14_ = _data_->path;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (_data_->_tmp14_ == NULL) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp16_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp17_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp18_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp19_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp20_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp21_ = 0;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_state_ = 2;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		boxes_tracker_iso_query_fetch_next_iso_data (_data_->self, boxes_tracker_iso_query_fetch_next_iso_data_ready, _data_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 850 "tracker-iso-query.c"
		_state_2:
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp22_ = FALSE;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp22_ = boxes_tracker_iso_query_fetch_next_iso_data_finish (_data_->self, _data_->_res_, &_data_->_tmp16_, &_data_->_tmp17_, &_data_->_tmp18_, &_data_->_tmp19_, &_data_->_tmp20_, &_data_->_tmp21_, &_data_->_inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->path);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->path = _data_->_tmp16_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->title);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->title = _data_->_tmp17_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->os_id);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->os_id = _data_->_tmp18_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->media_id);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->media_id = _data_->_tmp19_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->lang_list = _data_->_tmp20_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->lang_list_length1 = _data_->_tmp21_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp15_ = _data_->_tmp22_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_error_free (_data_->_inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_g_object_unref0 (_data_->file);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			if (_data_->_state_ == 0) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 892 "tracker-iso-query.c"
			} else {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 896 "tracker-iso-query.c"
			}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_object_unref (_data_->_async_result);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			return FALSE;
#line 902 "tracker-iso-query.c"
		}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->result = _data_->_tmp15_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_object_unref0 (_data_->file);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (_data_->_state_ == 0) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 912 "tracker-iso-query.c"
		} else {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 916 "tracker-iso-query.c"
		}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_object_unref (_data_->_async_result);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return FALSE;
#line 922 "tracker-iso-query.c"
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp23_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp23_ = _data_->self->priv->cursor;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp24_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp24_ = tracker_sparql_cursor_get_string (_data_->_tmp23_, 1, NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp25_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp25_ = g_strdup (_data_->_tmp24_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->title);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->title = _data_->_tmp25_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp26_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp26_ = _data_->self->priv->cursor;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp27_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp27_ = tracker_sparql_cursor_get_string (_data_->_tmp26_, 2, NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp28_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp28_ = g_strdup (_data_->_tmp27_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->os_id);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->os_id = _data_->_tmp28_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp29_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp29_ = _data_->self->priv->cursor;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp30_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp30_ = tracker_sparql_cursor_get_string (_data_->_tmp29_, 3, NULL);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp31_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp31_ = g_strdup (_data_->_tmp30_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_free0 (_data_->media_id);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->media_id = _data_->_tmp31_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp32_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp32_ = _data_->self->priv->cursor;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp33_ = 0;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp33_ = tracker_sparql_cursor_get_n_columns (_data_->_tmp32_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp34_ = 0;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->_tmp34_ = _data_->_tmp33_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (_data_->_tmp34_ > 4) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp35_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp35_ = _data_->self->priv->cursor;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp36_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp36_ = tracker_sparql_cursor_get_string (_data_->_tmp35_, 4, NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp37_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp37_ = g_strdup (_data_->_tmp36_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->languages = _data_->_tmp37_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp38__length1 = 0;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->__tmp38__size_ = 0;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp39_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp39_ = _data_->languages;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (_data_->_tmp39_ != NULL) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp40_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp40_ = _data_->languages;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp41_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp42_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp42_ = _data_->_tmp41_ = g_strsplit (_data_->_tmp40_, ",", 0);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp38_ = (_vala_array_free (_data_->_tmp38_, _data_->_tmp38__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp38_ = _data_->_tmp42_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp38__length1 = _vala_array_length (_data_->_tmp41_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->__tmp38__size_ = _data_->_tmp38__length1;
#line 1028 "tracker-iso-query.c"
		} else {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp43_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp43_ = g_new0 (gchar*, 0 + 1);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp38_ = (_vala_array_free (_data_->_tmp38_, _data_->_tmp38__length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp38_ = _data_->_tmp43_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->_tmp38__length1 = 0;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			_data_->__tmp38__size_ = _data_->_tmp38__length1;
#line 1042 "tracker-iso-query.c"
		}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp44_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp44__length1 = 0;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp44_ = (_data_->_tmp38_ != NULL) ? _vala_array_dup7 (_data_->_tmp38_, _data_->_tmp38__length1) : ((gpointer) _data_->_tmp38_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp44__length1 = _data_->_tmp38__length1;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->lang_list = (_vala_array_free (_data_->lang_list, _data_->lang_list_length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->lang_list = _data_->_tmp44_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->lang_list_length1 = _data_->_tmp44__length1;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_data_->_tmp38_ = (_vala_array_free (_data_->_tmp38_, _data_->_tmp38__length1, (GDestroyNotify) g_free), NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		_g_free0 (_data_->languages);
#line 1062 "tracker-iso-query.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_data_->result = TRUE;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (_data_->file);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (_data_->_state_ == 0) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1072 "tracker-iso-query.c"
	} else {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1076 "tracker-iso-query.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_object_unref (_data_->_async_result);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return FALSE;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (_data_->file);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (_data_->_state_ == 0) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1088 "tracker-iso-query.c"
	} else {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1092 "tracker-iso-query.c"
	}
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_object_unref (_data_->_async_result);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return FALSE;
#line 1098 "tracker-iso-query.c"
}


static void boxes_value_tracker_iso_query_init (GValue* value) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	value->data[0].v_pointer = NULL;
#line 1105 "tracker-iso-query.c"
}


static void boxes_value_tracker_iso_query_free_value (GValue* value) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (value->data[0].v_pointer) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		boxes_tracker_iso_query_unref (value->data[0].v_pointer);
#line 1114 "tracker-iso-query.c"
	}
}


static void boxes_value_tracker_iso_query_copy_value (const GValue* src_value, GValue* dest_value) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (src_value->data[0].v_pointer) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		dest_value->data[0].v_pointer = boxes_tracker_iso_query_ref (src_value->data[0].v_pointer);
#line 1124 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1128 "tracker-iso-query.c"
	}
}


static gpointer boxes_value_tracker_iso_query_peek_pointer (const GValue* value) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return value->data[0].v_pointer;
#line 1136 "tracker-iso-query.c"
}


static gchar* boxes_value_tracker_iso_query_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (collect_values[0].v_pointer) {
#line 1143 "tracker-iso-query.c"
		BoxesTrackerISOQuery* object;
		object = collect_values[0].v_pointer;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		if (object->parent_instance.g_class == NULL) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1150 "tracker-iso-query.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1154 "tracker-iso-query.c"
		}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		value->data[0].v_pointer = boxes_tracker_iso_query_ref (object);
#line 1158 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		value->data[0].v_pointer = NULL;
#line 1162 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return NULL;
#line 1166 "tracker-iso-query.c"
}


static gchar* boxes_value_tracker_iso_query_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesTrackerISOQuery** object_p;
	object_p = collect_values[0].v_pointer;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (!object_p) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1177 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (!value->data[0].v_pointer) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*object_p = NULL;
#line 1183 "tracker-iso-query.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*object_p = value->data[0].v_pointer;
#line 1187 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		*object_p = boxes_tracker_iso_query_ref (value->data[0].v_pointer);
#line 1191 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return NULL;
#line 1195 "tracker-iso-query.c"
}


GParamSpec* boxes_param_spec_tracker_iso_query (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecTrackerISOQuery* spec;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_TRACKER_ISO_QUERY), NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return G_PARAM_SPEC (spec);
#line 1209 "tracker-iso-query.c"
}


gpointer boxes_value_get_tracker_iso_query (const GValue* value) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_TRACKER_ISO_QUERY), NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return value->data[0].v_pointer;
#line 1218 "tracker-iso-query.c"
}


void boxes_value_set_tracker_iso_query (GValue* value, gpointer v_object) {
	BoxesTrackerISOQuery* old;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_TRACKER_ISO_QUERY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	old = value->data[0].v_pointer;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (v_object) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_TRACKER_ISO_QUERY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		value->data[0].v_pointer = v_object;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		boxes_tracker_iso_query_ref (value->data[0].v_pointer);
#line 1238 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		value->data[0].v_pointer = NULL;
#line 1242 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (old) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		boxes_tracker_iso_query_unref (old);
#line 1248 "tracker-iso-query.c"
	}
}


void boxes_value_take_tracker_iso_query (GValue* value, gpointer v_object) {
	BoxesTrackerISOQuery* old;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_TRACKER_ISO_QUERY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	old = value->data[0].v_pointer;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (v_object) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_TRACKER_ISO_QUERY));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		value->data[0].v_pointer = v_object;
#line 1267 "tracker-iso-query.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		value->data[0].v_pointer = NULL;
#line 1271 "tracker-iso-query.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (old) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		boxes_tracker_iso_query_unref (old);
#line 1277 "tracker-iso-query.c"
	}
}


static void boxes_tracker_iso_query_class_init (BoxesTrackerISOQueryClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	boxes_tracker_iso_query_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	((BoxesTrackerISOQueryClass *) klass)->finalize = boxes_tracker_iso_query_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_type_class_add_private (klass, sizeof (BoxesTrackerISOQueryPrivate));
#line 1289 "tracker-iso-query.c"
}


static void boxes_tracker_iso_query_instance_init (BoxesTrackerISOQuery * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	self->priv = BOXES_TRACKER_ISO_QUERY_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	self->ref_count = 1;
#line 1298 "tracker-iso-query.c"
}


static void boxes_tracker_iso_query_finalize (BoxesTrackerISOQuery* obj) {
	BoxesTrackerISOQuery * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TRACKER_ISO_QUERY, BoxesTrackerISOQuery);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_signal_handlers_destroy (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	_g_object_unref0 (self->priv->cursor);
#line 1310 "tracker-iso-query.c"
}


GType boxes_tracker_iso_query_get_type (void) {
	static volatile gsize boxes_tracker_iso_query_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_tracker_iso_query_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_tracker_iso_query_init, boxes_value_tracker_iso_query_free_value, boxes_value_tracker_iso_query_copy_value, boxes_value_tracker_iso_query_peek_pointer, "p", boxes_value_tracker_iso_query_collect_value, "p", boxes_value_tracker_iso_query_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesTrackerISOQueryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_tracker_iso_query_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesTrackerISOQuery), 0, (GInstanceInitFunc) boxes_tracker_iso_query_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_tracker_iso_query_type_id;
		boxes_tracker_iso_query_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesTrackerISOQuery", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_tracker_iso_query_type_id__volatile, boxes_tracker_iso_query_type_id);
	}
	return boxes_tracker_iso_query_type_id__volatile;
}


gpointer boxes_tracker_iso_query_ref (gpointer instance) {
	BoxesTrackerISOQuery* self;
	self = instance;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	g_atomic_int_inc (&self->ref_count);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	return instance;
#line 1335 "tracker-iso-query.c"
}


void boxes_tracker_iso_query_unref (gpointer instance) {
	BoxesTrackerISOQuery* self;
	self = instance;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		BOXES_TRACKER_ISO_QUERY_GET_CLASS (self)->finalize (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/tracker-iso-query.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1348 "tracker-iso-query.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 1356 "tracker-iso-query.c"
		int i;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 1364 "tracker-iso-query.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1376 "tracker-iso-query.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 1389 "tracker-iso-query.c"
		}
	}
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 1394 "tracker-iso-query.c"
}



