/* display-page.c generated by valac 0.34.0.71-0c51, the Vala compiler
 * generated from display-page.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <cairo.h>
#include <float.h>
#include <math.h>


#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;
typedef struct _BoxesDisplayPagePrivate BoxesDisplayPagePrivate;

#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;
typedef struct _Block21Data Block21Data;

struct _BoxesDisplayPage {
	GtkBox parent_instance;
	BoxesDisplayPagePrivate * priv;
	BoxesDisplayToolbar* toolbar;
	GtkLabel* size_label;
};

struct _BoxesDisplayPageClass {
	GtkBoxClass parent_class;
};

struct _BoxesDisplayPagePrivate {
	GtkEventBox* event_box;
	BoxesDisplayToolbar* overlay_toolbar;
	GtkEventBox* overlay_toolbar_box;
	guint toolbar_hide_id;
	guint toolbar_show_id;
	gulong cursor_id;
	guint overlay_toolbar_invisible_timeout;
	guint size_label_timeout;
	BoxesAppWindow* window;
	BoxesDisplay* display;
	gulong can_grab_mouse_id;
	gulong mouse_grabbed_id;
	gulong keyboard_grabbed_id;
	gint width;
	gint height;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _Block21Data {
	int _ref_count_;
	BoxesDisplayPage* self;
	gulong draw_id;
	GtkWidget* widget;
};


static gpointer boxes_display_page_parent_class = NULL;

GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPagePrivate))
enum  {
	BOXES_DISPLAY_PAGE_DUMMY_PROPERTY
};
static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self);
#define BOXES_DISPLAY_PAGE_SCREEN_EDGE_WIDTH ((guint8) 100)
void boxes_display_page_setup_ui (BoxesDisplayPage* self, BoxesAppWindow* window);
#define BOXES_APP_WINDOW_TRANSITION_DURATION ((guint) 400)
static gboolean __lambda169_ (BoxesDisplayPage* self, GdkEventWindowState* event);
static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self);
static gboolean ___lambda169__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
void boxes_display_toolbar_setup_ui (BoxesDisplayToolbar* self, BoxesAppWindow* window);
gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self);
static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self);
static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible);
void boxes_display_page_update_subtitle (BoxesDisplayPage* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
static gboolean boxes_display_page_get_mouse_grabbed (BoxesDisplayPage* self);
static gboolean boxes_display_page_get_keyboard_grabbed (BoxesDisplayPage* self);
void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
void boxes_display_page_replace_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
static Block21Data* block21_data_ref (Block21Data* _data21_);
static void block21_data_unref (void * _userdata_);
GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self);
static void __lambda83_ (BoxesDisplayPage* self);
static gboolean __lambda84_ (BoxesDisplayPage* self);
static gboolean ___lambda84__gsource_func (gpointer self);
static void ___lambda83__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda85_ (BoxesDisplayPage* self);
static gboolean __lambda86_ (BoxesDisplayPage* self);
static gboolean ___lambda86__gsource_func (gpointer self);
static void ___lambda85__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda87_ (BoxesDisplayPage* self);
static void ___lambda87__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda88_ (BoxesDisplayPage* self);
static gboolean ___lambda88__gsource_func (gpointer self);
static gboolean __lambda89_ (Block21Data* _data21_);
static void __lambda90_ (Block21Data* _data21_);
static void ___lambda90__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean ___lambda89__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
static gboolean boxes_display_page_on_event_box_event (BoxesDisplayPage* self, GdkEvent* event);
static gboolean _____lambda170_ (BoxesDisplayPage* self);
static gboolean ______lambda170__gsource_func (gpointer self);
static gboolean _____lambda171_ (BoxesDisplayPage* self);
static gboolean ______lambda171__gsource_func (gpointer self);
static gboolean _boxes_display_page_on_event_box_event_gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self);
static void boxes_display_page_on_size_allocate (BoxesDisplayPage* self, GtkAllocation* allocation);
static gboolean __lambda172_ (BoxesDisplayPage* self);
static void boxes_display_page_show_size_allocation (BoxesDisplayPage* self);
static gboolean ___lambda172__gsource_func (gpointer self);
static void _boxes_display_page_on_size_allocate_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static gboolean __lambda173_ (BoxesDisplayPage* self);
static gboolean ___lambda173__gsource_func (gpointer self);
BoxesDisplayPage* boxes_display_page_new (void);
BoxesDisplayPage* boxes_display_page_construct (GType object_type);
gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self);
gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self);
gboolean boxes_display_get_keyboard_grabbed (BoxesDisplay* self);
static void boxes_display_page_finalize (GObject* obj);
static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static gpointer _g_object_ref0 (gpointer self) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return self ? g_object_ref (self) : NULL;
#line 308 "display-page.c"
}


static gboolean __lambda169_ (BoxesDisplayPage* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 322 "display-page.c"
}


static gboolean ___lambda169__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = __lambda169_ ((BoxesDisplayPage*) self, event);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 331 "display-page.c"
}


void boxes_display_page_setup_ui (BoxesDisplayPage* self, BoxesAppWindow* window) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	GtkEventBox* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesDisplayToolbar* _tmp4_ = NULL;
	BoxesDisplayToolbar* _tmp5_ = NULL;
	BoxesDisplayToolbar* _tmp6_ = NULL;
	BoxesDisplayToolbar* _tmp7_ = NULL;
	BoxesDisplayToolbar* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
	BoxesDisplayToolbar* _tmp10_ = NULL;
	BoxesAppWindow* _tmp11_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (window != NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = window;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->window);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->window = _tmp1_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = BOXES_APP_WINDOW_TRANSITION_DURATION;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->event_box;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events ((GtkWidget*) _tmp2_, (gint) (GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK));
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = window;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_object ((GtkWidget*) _tmp3_, "window-state-event", (GCallback) ___lambda169__gtk_widget_window_state_event, self, 0);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = self->toolbar;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = self->priv->overlay_toolbar;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp4_, "title", (GObject*) _tmp5_, "title", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->toolbar;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = self->priv->overlay_toolbar;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp6_, "subtitle", (GObject*) _tmp7_, "subtitle", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = self->toolbar;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = window;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_toolbar_setup_ui (_tmp8_, _tmp9_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = self->priv->overlay_toolbar;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = window;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_toolbar_setup_ui (_tmp10_, _tmp11_);
#line 394 "display-page.c"
}


static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self) {
	gboolean _tmp0_ = FALSE;
	BoxesAppWindow* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->window;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_window_get_fullscreened (_tmp1_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 413 "display-page.c"
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = boxes_display_page_get_can_grab_mouse (self);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp5_;
#line 422 "display-page.c"
	} else {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 426 "display-page.c"
	}
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_) {
#line 430 "display-page.c"
		BoxesDisplayToolbar* _tmp6_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp6_ = self->toolbar;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp6_, TRUE);
#line 436 "display-page.c"
	} else {
		BoxesDisplayToolbar* _tmp7_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->toolbar;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp7_, FALSE);
#line 443 "display-page.c"
	}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 447 "display-page.c"
}


static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkEventBox* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = visible;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_) {
#line 462 "display-page.c"
		BoxesDisplayToolbar* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->toolbar;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = gtk_widget_get_visible ((GtkWidget*) _tmp2_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 474 "display-page.c"
	} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 478 "display-page.c"
	}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_debug ("display-page.vala:83: toolbar is visible, don't show overlay toolbar");
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		return;
#line 486 "display-page.c"
	}
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = self->priv->overlay_toolbar_box;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = visible;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp5_, _tmp6_);
#line 494 "display-page.c"
}


static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self) {
	guint _tmp0_ = 0U;
	guint _tmp2_ = 0U;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->toolbar_hide_id;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 507 "display-page.c"
		guint _tmp1_ = 0U;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->toolbar_hide_id;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp1_);
#line 513 "display-page.c"
	}
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->toolbar_show_id;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 521 "display-page.c"
		guint _tmp3_ = 0U;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = self->priv->toolbar_show_id;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp3_);
#line 527 "display-page.c"
	}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_show_id = (guint) 0;
#line 531 "display-page.c"
}


void boxes_display_page_update_subtitle (BoxesDisplayPage* self) {
	BoxesMachine* machine = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	BoxesMachine* _tmp4_ = NULL;
	gchar* hint = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	BoxesDisplayToolbar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->window;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _tmp1_;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	machine = _tmp3_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = machine;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (_tmp4_ != NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	hint = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_display_page_get_can_grab_mouse (self);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp6_) {
#line 571 "display-page.c"
		gboolean _tmp7_ = FALSE;
		gboolean _tmp8_ = FALSE;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = boxes_display_page_get_mouse_grabbed (self);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = _tmp7_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp8_) {
#line 580 "display-page.c"
			const gchar* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp9_ = _ ("Press (left) Ctrl+Alt to ungrab");
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp10_ = g_strdup (_tmp9_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_g_free0 (hint);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			hint = _tmp10_;
#line 591 "display-page.c"
		}
	} else {
		gboolean _tmp11_ = FALSE;
		gboolean _tmp12_ = FALSE;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = boxes_display_page_get_keyboard_grabbed (self);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp12_ = _tmp11_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp12_) {
#line 602 "display-page.c"
			const gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp13_ = _ ("Press & release (left) Ctrl+Alt to ungrab keyboard.");
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp14_ = g_strdup (_tmp13_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_g_free0 (hint);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			hint = _tmp14_;
#line 613 "display-page.c"
		}
	}
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = self->toolbar;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = hint;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_header_bar_set_subtitle ((GtkHeaderBar*) _tmp15_, _tmp16_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_free0 (hint);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (machine);
#line 626 "display-page.c"
}


void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget) {
	BoxesDisplay* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	GtkStack* _tmp3_ = NULL;
	GtkWidget* _tmp4_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (display != NULL);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (widget != NULL);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = display;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = widget;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_replace_display (self, _tmp0_, _tmp1_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->window;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_->below_bin;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_stack_set_visible_child_name (_tmp3_, "display-page");
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = widget;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_grab_focus (_tmp4_);
#line 658 "display-page.c"
}


static Block21Data* block21_data_ref (Block21Data* _data21_) {
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_atomic_int_inc (&_data21_->_ref_count_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return _data21_;
#line 667 "display-page.c"
}


static void block21_data_unref (void * _userdata_) {
	Block21Data* _data21_;
	_data21_ = (Block21Data*) _userdata_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (g_atomic_int_dec_and_test (&_data21_->_ref_count_)) {
#line 676 "display-page.c"
		BoxesDisplayPage* self;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self = _data21_->self;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (_data21_->widget);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (self);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_slice_free (Block21Data, _data21_);
#line 686 "display-page.c"
	}
}


static gboolean __lambda84_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_subtitle (self);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 699 "display-page.c"
}


static gboolean ___lambda84__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda84_ ((BoxesDisplayPage*) self);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 708 "display-page.c"
}


static void __lambda83_ (BoxesDisplayPage* self) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_HIGH, ___lambda84__gsource_func, g_object_ref (self), g_object_unref);
#line 715 "display-page.c"
}


static void ___lambda83__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda83_ ((BoxesDisplayPage*) self);
#line 722 "display-page.c"
}


static gboolean __lambda86_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_subtitle (self);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 734 "display-page.c"
}


static gboolean ___lambda86__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda86_ ((BoxesDisplayPage*) self);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 743 "display-page.c"
}


static void __lambda85_ (BoxesDisplayPage* self) {
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_HIGH, ___lambda86__gsource_func, g_object_ref (self), g_object_unref);
#line 750 "display-page.c"
}


static void ___lambda85__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda85_ ((BoxesDisplayPage*) self);
#line 757 "display-page.c"
}


static void __lambda87_ (BoxesDisplayPage* self) {
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 764 "display-page.c"
}


static void ___lambda87__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda87_ ((BoxesDisplayPage*) self);
#line 771 "display-page.c"
}


static gboolean __lambda88_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
	BoxesAppWindow* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = (guint) 1000;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->window;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_window_get_fullscreened (_tmp0_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _tmp1_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, _tmp2_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 796 "display-page.c"
}


static gboolean ___lambda88__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda88_ ((BoxesDisplayPage*) self);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 805 "display-page.c"
}


static void __lambda90_ (Block21Data* _data21_) {
	BoxesDisplayPage* self;
	GtkEventBox* _tmp0_ = NULL;
	GdkWindow* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GdkWindow* _tmp3_ = NULL;
	GdkCursor* _tmp4_ = NULL;
	GdkCursor* _tmp5_ = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data21_->self;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->event_box;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = gtk_widget_get_window ((GtkWidget*) _tmp0_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data21_->widget;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = gdk_window_get_cursor (_tmp3_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp4_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gdk_window_set_cursor (_tmp1_, _tmp5_);
#line 833 "display-page.c"
}


static void ___lambda90__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda90_ (self);
#line 840 "display-page.c"
}


static gboolean __lambda89_ (Block21Data* _data21_) {
	BoxesDisplayPage* self;
	gboolean result = FALSE;
	GtkWidget* _tmp0_ = NULL;
	gulong _tmp1_ = 0UL;
	GtkWidget* _tmp2_ = NULL;
	GdkWindow* _tmp3_ = NULL;
	gulong _tmp4_ = 0UL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data21_->self;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = _data21_->widget;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _data21_->draw_id;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data21_->widget;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = g_signal_connect_data ((GObject*) _tmp3_, "notify::cursor", (GCallback) ___lambda90__g_object_notify, block21_data_ref (_data21_), (GClosureNotify) block21_data_unref, 0);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->cursor_id = _tmp4_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 872 "display-page.c"
}


static gboolean ___lambda89__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda89_ (self);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 881 "display-page.c"
}


void boxes_display_page_replace_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget) {
	Block21Data* _data21_;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkEventBox* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	GtkWidget* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
	GtkWidget* _tmp6_ = NULL;
	BoxesDisplay* _tmp7_ = NULL;
	BoxesDisplay* _tmp8_ = NULL;
	BoxesDisplay* _tmp9_ = NULL;
	gulong _tmp10_ = 0UL;
	BoxesDisplay* _tmp11_ = NULL;
	gulong _tmp12_ = 0UL;
	BoxesDisplay* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
	GtkWidget* _tmp15_ = NULL;
	GtkWidget* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	GtkEventBox* _tmp18_ = NULL;
	GtkWidget* _tmp19_ = NULL;
	GtkEventBox* _tmp20_ = NULL;
	GtkWidget* _tmp21_ = NULL;
	gulong _tmp22_ = 0UL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (display != NULL);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (widget != NULL);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data21_ = g_slice_new0 (Block21Data);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data21_->_ref_count_ = 1;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data21_->self = g_object_ref (self);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = widget;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_data21_->widget);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data21_->widget = _tmp1_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->event_box;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_bin_get_child ((GtkBin*) _tmp2_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = _data21_->widget;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_ == _tmp4_) {
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		block21_data_unref (_data21_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_data21_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		return;
#line 944 "display-page.c"
	}
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_display_page_remove_display (self);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_tmp6_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = display;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display = _tmp8_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = display;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = g_signal_connect_object ((GObject*) _tmp9_, "notify::mouse-grabbed", (GCallback) ___lambda83__g_object_notify, self, 0);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->mouse_grabbed_id = _tmp10_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = display;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = g_signal_connect_object ((GObject*) _tmp11_, "notify::keyboard-grabbed", (GCallback) ___lambda85__g_object_notify, self, 0);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->keyboard_grabbed_id = _tmp12_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = display;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = g_signal_connect_object ((GObject*) _tmp13_, "notify::can-grab-mouse", (GCallback) ___lambda87__g_object_notify, self, 0);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->can_grab_mouse_id = _tmp14_;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda88__gsource_func, g_object_ref (self), g_object_unref);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_subtitle (self);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = _data21_->widget;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = _data21_->widget;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp17_ = gtk_widget_get_events (_tmp16_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events (_tmp15_, _tmp17_ & (~GDK_POINTER_MOTION_MASK));
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp18_ = self->priv->event_box;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp19_ = _data21_->widget;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) _tmp18_, _tmp19_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp20_ = self->priv->event_box;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp20_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data21_->draw_id = (gulong) 0;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp21_ = _data21_->widget;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp22_ = g_signal_connect_data (_tmp21_, "draw", (GCallback) ___lambda89__gtk_widget_draw, block21_data_ref (_data21_), (GClosureNotify) block21_data_unref, 0);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data21_->draw_id = _tmp22_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	block21_data_unref (_data21_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data21_ = NULL;
#line 1014 "display-page.c"
}


GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self) {
	GtkWidget* result = NULL;
	gulong _tmp0_ = 0UL;
	gulong _tmp3_ = 0UL;
	gulong _tmp6_ = 0UL;
	GtkWidget* widget = NULL;
	GtkEventBox* _tmp9_ = NULL;
	GtkWidget* _tmp10_ = NULL;
	GtkWidget* _tmp11_ = NULL;
	gulong _tmp12_ = 0UL;
	GtkWidget* _tmp16_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->mouse_grabbed_id;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 1035 "display-page.c"
		BoxesDisplay* _tmp1_ = NULL;
		gulong _tmp2_ = 0UL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->display;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->mouse_grabbed_id;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->mouse_grabbed_id = (gulong) 0;
#line 1046 "display-page.c"
	}
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = self->priv->can_grab_mouse_id;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_ != ((gulong) 0)) {
#line 1052 "display-page.c"
		BoxesDisplay* _tmp4_ = NULL;
		gulong _tmp5_ = 0UL;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = self->priv->display;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = self->priv->can_grab_mouse_id;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp4_, _tmp5_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->can_grab_mouse_id = (gulong) 0;
#line 1063 "display-page.c"
	}
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->priv->keyboard_grabbed_id;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp6_ != ((gulong) 0)) {
#line 1069 "display-page.c"
		BoxesDisplay* _tmp7_ = NULL;
		gulong _tmp8_ = 0UL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->priv->display;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = self->priv->keyboard_grabbed_id;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp7_, _tmp8_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->keyboard_grabbed_id = (gulong) 0;
#line 1080 "display-page.c"
	}
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = self->priv->event_box;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = gtk_bin_get_child ((GtkBin*) _tmp9_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	widget = _tmp11_;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = self->priv->cursor_id;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp12_ != ((gulong) 0)) {
#line 1098 "display-page.c"
		GtkWidget* _tmp13_ = NULL;
		GdkWindow* _tmp14_ = NULL;
		gulong _tmp15_ = 0UL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp13_ = widget;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp14_ = gtk_widget_get_window (_tmp13_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp15_ = self->priv->cursor_id;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp14_, _tmp15_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->cursor_id = (gulong) 0;
#line 1112 "display-page.c"
	}
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = widget;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp16_ != NULL) {
#line 1118 "display-page.c"
		GtkEventBox* _tmp17_ = NULL;
		GtkWidget* _tmp18_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp17_ = self->priv->event_box;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp18_ = widget;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_container_remove ((GtkContainer*) _tmp17_, _tmp18_);
#line 1127 "display-page.c"
	}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = widget;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1133 "display-page.c"
}


static gboolean _____lambda170_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, TRUE);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_show_id = (guint) 0;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1147 "display-page.c"
}


static gboolean ______lambda170__gsource_func (gpointer self) {
	gboolean result;
	result = _____lambda170_ ((BoxesDisplayPage*) self);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1156 "display-page.c"
}


static gboolean _____lambda171_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = BOXES_APP_WINDOW_TRANSITION_DURATION;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1172 "display-page.c"
}


static gboolean ______lambda171__gsource_func (gpointer self) {
	gboolean result;
	result = _____lambda171_ ((BoxesDisplayPage*) self);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1181 "display-page.c"
}


static gboolean boxes_display_page_on_event_box_event (BoxesDisplayPage* self, GdkEvent* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesAppWindow* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GdkEvent* _tmp32_ = NULL;
	GdkEventType _tmp33_ = 0;
	GtkEventBox* _tmp34_ = NULL;
	GtkWidget* _tmp35_ = NULL;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->window;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_window_get_fullscreened (_tmp1_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 1207 "display-page.c"
		GdkEvent* _tmp4_ = NULL;
		GdkEventType _tmp5_ = 0;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = event;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_->type;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp5_ == GDK_MOTION_NOTIFY;
#line 1216 "display-page.c"
	} else {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1220 "display-page.c"
	}
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_) {
#line 1224 "display-page.c"
		gdouble x = 0.0;
		GdkEvent* _tmp6_ = NULL;
		GdkEventMotion* _tmp7_ = NULL;
		GdkEventMotion* _tmp8_ = NULL;
		gdouble _tmp9_ = 0.0;
		gdouble y = 0.0;
		GdkEvent* _tmp10_ = NULL;
		GdkEventMotion* _tmp11_ = NULL;
		GdkEventMotion* _tmp12_ = NULL;
		gdouble _tmp13_ = 0.0;
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_ = FALSE;
		gboolean _tmp16_ = FALSE;
		gdouble _tmp17_ = 0.0;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp6_ = event;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = (GdkEventMotion *) (_tmp6_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = _tmp7_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp9_ = _tmp8_->x;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		x = _tmp9_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = event;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = (GdkEventMotion *) (_tmp10_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp12_ = _tmp11_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp13_ = _tmp12_->y;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		y = _tmp13_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp17_ = x;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp17_ >= ((gdouble) BOXES_DISPLAY_PAGE_SCREEN_EDGE_WIDTH)) {
#line 1263 "display-page.c"
			gdouble _tmp18_ = 0.0;
			gint _tmp19_ = 0;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp18_ = x;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp19_ = gtk_widget_get_allocated_width ((GtkWidget*) self);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp16_ = _tmp18_ <= ((gdouble) (_tmp19_ - BOXES_DISPLAY_PAGE_SCREEN_EDGE_WIDTH));
#line 1272 "display-page.c"
		} else {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp16_ = FALSE;
#line 1276 "display-page.c"
		}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp16_) {
#line 1280 "display-page.c"
			gdouble _tmp20_ = 0.0;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp20_ = y;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp15_ = _tmp20_ <= ((gdouble) 0);
#line 1286 "display-page.c"
		} else {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp15_ = FALSE;
#line 1290 "display-page.c"
		}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp15_) {
#line 1294 "display-page.c"
			guint _tmp21_ = 0U;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp21_ = self->priv->toolbar_show_id;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp14_ = _tmp21_ == ((guint) 0);
#line 1300 "display-page.c"
		} else {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp14_ = FALSE;
#line 1304 "display-page.c"
		}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp14_) {
#line 1308 "display-page.c"
			GdkEvent* _tmp22_ = NULL;
			GdkEventMotion* _tmp23_ = NULL;
			GdkEventMotion* _tmp24_ = NULL;
			GdkModifierType _tmp25_ = 0;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			boxes_display_page_toolbar_event_stop (self);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp22_ = event;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp23_ = (GdkEventMotion *) (_tmp22_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp24_ = _tmp23_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp25_ = _tmp24_->state;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			if ((_tmp25_ & ((((((((((GDK_SHIFT_MASK | GDK_CONTROL_MASK) | GDK_MOD1_MASK) | GDK_SUPER_MASK) | GDK_HYPER_MASK) | GDK_META_MASK) | GDK_BUTTON1_MASK) | GDK_BUTTON2_MASK) | GDK_BUTTON3_MASK) | GDK_BUTTON4_MASK) | GDK_BUTTON5_MASK)) == 0) {
#line 1325 "display-page.c"
				guint _tmp26_ = 0U;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp26_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_APP_WINDOW_TRANSITION_DURATION, ______lambda170__gsource_func, g_object_ref (self), g_object_unref);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				self->priv->toolbar_show_id = _tmp26_;
#line 1331 "display-page.c"
			}
		} else {
			gboolean _tmp27_ = FALSE;
			gdouble _tmp28_ = 0.0;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp28_ = y;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			if (_tmp28_ > ((gdouble) 5)) {
#line 1340 "display-page.c"
				guint _tmp29_ = 0U;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp29_ = self->priv->toolbar_hide_id;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp27_ = _tmp29_ == ((guint) 0);
#line 1346 "display-page.c"
			} else {
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp27_ = FALSE;
#line 1350 "display-page.c"
			}
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			if (_tmp27_) {
#line 1354 "display-page.c"
				guint _tmp30_ = 0U;
				guint _tmp31_ = 0U;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				boxes_display_page_toolbar_event_stop (self);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp30_ = self->priv->overlay_toolbar_invisible_timeout;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp31_ = g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp30_, ______lambda171__gsource_func, g_object_ref (self), g_object_unref);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				self->priv->toolbar_hide_id = _tmp31_;
#line 1365 "display-page.c"
			}
		}
	}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp32_ = event;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp33_ = _tmp32_->type;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp33_ == GDK_GRAB_BROKEN) {
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		result = FALSE;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		return result;
#line 1379 "display-page.c"
	}
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp34_ = self->priv->event_box;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp35_ = gtk_bin_get_child ((GtkBin*) _tmp34_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp35_ != NULL) {
#line 1387 "display-page.c"
		GtkEventBox* _tmp36_ = NULL;
		GtkWidget* _tmp37_ = NULL;
		GdkEvent* _tmp38_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp36_ = self->priv->event_box;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp37_ = gtk_bin_get_child ((GtkBin*) _tmp36_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp38_ = event;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_event (_tmp37_, _tmp38_);
#line 1399 "display-page.c"
	}
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1405 "display-page.c"
}


static gboolean _boxes_display_page_on_event_box_event_gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self) {
	gboolean result;
	result = boxes_display_page_on_event_box_event ((BoxesDisplayPage*) self, event);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1414 "display-page.c"
}


static gboolean __lambda172_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_show_size_allocation (self);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1426 "display-page.c"
}


static gboolean ___lambda172__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda172_ ((BoxesDisplayPage*) self);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1435 "display-page.c"
}


static void boxes_display_page_on_size_allocate (BoxesDisplayPage* self, GtkAllocation* allocation) {
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	GtkAllocation _tmp2_ = {0};
	gint _tmp3_ = 0;
	GtkAllocation _tmp7_ = {0};
	gint _tmp8_ = 0;
	GtkAllocation _tmp9_ = {0};
	gint _tmp10_ = 0;
	GtkLabel* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	GtkAllocation _tmp13_ = {0};
	gint _tmp14_ = 0;
	GtkAllocation _tmp15_ = {0};
	gint _tmp16_ = 0;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (allocation != NULL);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->width;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = *allocation;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_.width;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ == _tmp3_) {
#line 1468 "display-page.c"
		gint _tmp4_ = 0;
		GtkAllocation _tmp5_ = {0};
		gint _tmp6_ = 0;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = self->priv->height;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = *allocation;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp6_ = _tmp5_.height;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_ == _tmp6_;
#line 1480 "display-page.c"
	} else {
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1484 "display-page.c"
	}
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_) {
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		return;
#line 1490 "display-page.c"
	}
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = *allocation;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = _tmp7_.width;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->width = _tmp8_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = *allocation;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = _tmp9_.height;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->height = _tmp10_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = self->size_label;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = _ ("%d×%d");
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = *allocation;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = _tmp13_.width;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = *allocation;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = _tmp15_.height;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp17_ = g_strdup_printf (_tmp12_, _tmp14_, _tmp16_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp18_ = _tmp17_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_label_set_label (_tmp11_, _tmp18_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_free0 (_tmp18_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda172__gsource_func, g_object_ref (self), g_object_unref);
#line 1526 "display-page.c"
}


static void _boxes_display_page_on_size_allocate_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_on_size_allocate ((BoxesDisplayPage*) self, allocation);
#line 1533 "display-page.c"
}


static gboolean __lambda173_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
	GtkLabel* _tmp0_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->size_label;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, FALSE);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->size_label_timeout = (guint) 0;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1550 "display-page.c"
}


static gboolean ___lambda173__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda173_ ((BoxesDisplayPage*) self);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1559 "display-page.c"
}


static void boxes_display_page_show_size_allocation (BoxesDisplayPage* self) {
	GtkLabel* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	guint _tmp3_ = 0U;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->size_label;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, TRUE);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->size_label_timeout;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != ((guint) 0)) {
#line 1577 "display-page.c"
		guint _tmp2_ = 0U;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->size_label_timeout;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp2_);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->size_label_timeout = (guint) 0;
#line 1585 "display-page.c"
	}
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 3, ___lambda173__gsource_func, g_object_ref (self), g_object_unref);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->size_label_timeout = _tmp3_;
#line 1591 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_construct (GType object_type) {
	BoxesDisplayPage * self = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayPage*) g_object_new (object_type, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return self;
#line 1601 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_new (void) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return boxes_display_page_construct (BOXES_TYPE_DISPLAY_PAGE);
#line 1608 "display-page.c"
}


static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesDisplay* _tmp1_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->display;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != NULL) {
#line 1622 "display-page.c"
		BoxesDisplay* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = boxes_display_get_can_grab_mouse (_tmp2_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 1634 "display-page.c"
	} else {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1638 "display-page.c"
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp0_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1644 "display-page.c"
}


static gboolean boxes_display_page_get_mouse_grabbed (BoxesDisplayPage* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesDisplay* _tmp1_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->display;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != NULL) {
#line 1658 "display-page.c"
		BoxesDisplay* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = boxes_display_get_mouse_grabbed (_tmp2_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 1670 "display-page.c"
	} else {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1674 "display-page.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp0_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1680 "display-page.c"
}


static gboolean boxes_display_page_get_keyboard_grabbed (BoxesDisplayPage* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesDisplay* _tmp1_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->display;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != NULL) {
#line 1694 "display-page.c"
		BoxesDisplay* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = boxes_display_get_keyboard_grabbed (_tmp2_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 1706 "display-page.c"
	} else {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1710 "display-page.c"
	}
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp0_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1716 "display-page.c"
}


static void boxes_display_page_class_init (BoxesDisplayPageClass * klass) {
	gint BoxesDisplayPage_private_offset;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayPagePrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_page_get_property;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_page_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	BoxesDisplayPage_private_offset = g_type_class_get_instance_private_offset (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/display-page.ui");
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "toolbar", FALSE, G_STRUCT_OFFSET (BoxesDisplayPage, toolbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "size_label", FALSE, G_STRUCT_OFFSET (BoxesDisplayPage, size_label));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "event_box", FALSE, BoxesDisplayPage_private_offset + G_STRUCT_OFFSET (BoxesDisplayPagePrivate, event_box));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "overlay_toolbar", FALSE, BoxesDisplayPage_private_offset + G_STRUCT_OFFSET (BoxesDisplayPagePrivate, overlay_toolbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "overlay_toolbar_box", FALSE, BoxesDisplayPage_private_offset + G_STRUCT_OFFSET (BoxesDisplayPagePrivate, overlay_toolbar_box));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_event_box_event", G_CALLBACK(_boxes_display_page_on_event_box_event_gtk_widget_event));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_size_allocate", G_CALLBACK(_boxes_display_page_on_size_allocate_gtk_widget_size_allocate));
#line 1748 "display-page.c"
}


static void boxes_display_page_instance_init (BoxesDisplayPage * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv = BOXES_DISPLAY_PAGE_GET_PRIVATE (self);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->width = -1;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->height = -1;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_type_ensure (BOXES_TYPE_DISPLAY_TOOLBAR);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1763 "display-page.c"
}


static void boxes_display_page_finalize (GObject* obj) {
	BoxesDisplayPage * self;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_toolbar_event_stop (self);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->toolbar);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->size_label);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->event_box);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar_box);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->window);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (boxes_display_page_parent_class)->finalize (obj);
#line 1789 "display-page.c"
}


GType boxes_display_page_get_type (void) {
	static volatile gsize boxes_display_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayPage), 0, (GInstanceInitFunc) boxes_display_page_instance_init, NULL };
		GType boxes_display_page_type_id;
		boxes_display_page_type_id = g_type_register_static (gtk_box_get_type (), "BoxesDisplayPage", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_page_type_id__volatile, boxes_display_page_type_id);
	}
	return boxes_display_page_type_id__volatile;
}


static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplayPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	switch (property_id) {
#line 1810 "display-page.c"
		default:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		break;
#line 1816 "display-page.c"
	}
}



